<template>
  <ProTabs
    v-model="queryState.mineAgreementSignType"
    name="home-tab"
    :showPaneContent="false"
    class="home-tabs"
    isTransparent
    title-gutter="12"
    title-scroll
  >
    <ProTabPane :title="`全部`" :pane-key="MineAgreementSignType.All"></ProTabPane>
    <ProTabPane :title="`待签约`" :pane-key="MineAgreementSignType.WaitSign"></ProTabPane>
    <ProTabPane :title="`生效中`" :pane-key="MineAgreementSignType.Effect"></ProTabPane>
    <ProTabPane :title="`已终止`" :pane-key="MineAgreementSignType.Terminated"></ProTabPane>
  </ProTabs>
  <InfiniteLoading
    scrollViewClassName="common-infinite-scroll-list home-list"
    v-bind="infiniteLoadingProps"
    :key="queryState.mineAgreementSignType"
  >
    <template #renderItem="{ item }">
      <MineAgreementSignCard @click="goDetail">
        <template #actions>
          <div class="task-card-actions-text" :style="{ color: MineAgreementSignTypeColor[10] }">
            {{ MineAgreementSignTypeText[10] }}
          </div>
        </template>
      </MineAgreementSignCard>
    </template>
  </InfiniteLoading>
</template>

<script setup lang="ts">
import { MineAgreementSignCard, ProTabs, ProTabPane } from '@12333/components';
import { useUserStore } from '@/stores/modules/user';
import {
  MineAgreementSignType,
  MineAgreementSignTypeColor,
  MineAgreementSignTypeText,
} from './constants';
import { useInfiniteLoading } from '@12333/hooks';
import { OrderInputType } from '@12333/constants';
import * as orderServices from '@12333/services/api/Order';
import Taro from '@tarojs/taro';

defineOptions({
  name: 'InnerPage',
});

const queryState = reactive({
  mineAgreementSignType: MineAgreementSignType.All,
});

const userStore = useUserStore();

const { infiniteLoadingProps } = useInfiniteLoading(
  ({ pageParam }) => {
    let params: API.FrontOrderListInput = {
      pageModel: {
        rows: 20,
        page: pageParam,
        orderInput: [
          queryState.mineAgreementSignType === MineAgreementSignType.All
            ? { property: 'isRecommend', order: OrderInputType.Desc }
            : { property: 'lastShelfTime', order: OrderInputType.Desc },
        ],
      },
    };

    return orderServices.getFrontOrderList(params, {
      showLoading: false,
    });
  },
  {
    queryKey: ['orderServices/getFrontOrderList', queryState],
  }
);

function goDetail() {
  Taro.navigateTo({
    url: RouterPath.mineAgreementSignDetail,
  });
}
</script>

<style lang="scss">
@import '@/styles/common.scss';

.task-card-actions-text {
  font-size: 24px;
  line-height: 42px;
}
</style>
